California Secretary of State - CalAccess - Campaign Finance

Advanced Search
| Candidates & Elected Officials
Propositions & Ballot Measures
Committees, Parties, Major Donors & Slate Mailers
Daily/Late/ Special Filings
| Campaign Finance: PROP 95 - REFERENDUM ON AMENDMENT TO INDIAN GAMING COMPACT. (CHAPTER 38, STATUTES OF 2007) View Information: General Information Late Independent Expenditures Affecting This Measure
How much money is being raised and spent to pass or defeat California propositions and ballot measures, and what are the sources of the money? Check here to follow the money trail.
Committees formed to support or oppose the ballot measure.
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1300196 | TRIBES FOR FAIR PLAY, NO ON 94, 95, 96, AND 97 | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1300272 | CALIFORNIANS AGAINST UNFAIR DEALS; NO ON 94, 95, 96, 97, A COALITION OF TRIBES FOR FAIR PLAY, BAY MEADOWS AND HOLLYWOOD PARK RACETRACKS, LABOR, TAXPAYERS, EDUCATORS, PUBLIC SAFETY OFFICIALS | OPPOSE
COMMITTEE ID | COMMITTEE NAME | COMMITTEE POSITION
1300585 | COALITION TO PROTECT CALIFORNIA'S BUDGET & ECONOMY, YES ON 94, 95, 96, 97, SPONSORED BY A GROUP OF INDIAN GAMING TRIBES | SUPPORT